@@ -204,6 +204,9 @@ pub mod train;
 mod saved_model;
 pub use saved_model::*;
 
+#[cfg(feature = "eager")]
+pub mod eager;
+
 ////////////////////////
 
 c_enum!("Error values that can be returned.", TF_Code, Code {
@@ -1434,8 +1437,28 @@ impl<'a, T: TensorType, const N: usize> From<&[T; N]> for Tensor<T> {
     }
 }
 
+#[cfg(feature = "ndarray")]
+/// Convert any &ndarray::ArrayBase type into a tensorflow::Tensor
+impl<T, S, D> From<&ArrayBase<S, D>> for Tensor<T>
+where
+    T: TensorType,
+    S: Data<Elem = T>,
+    D: Dimension,
+{
+    fn from(value: &ArrayBase<S, D>) -> Self {
+        let dims: Vec<u64> = value.shape().iter().map(|x| *x as u64).collect();
+        let mut tensor: Tensor<T> = Self::new(&dims);
+        for (e, v) in tensor.iter_mut().zip(value.iter()) {
+            e.clone_from(v);
+        }
+        tensor
+    }
+}
+
 #[cfg(feature = "ndarray")]
 /// Convert any ndarray::ArrayBase type into a tensorflow::Tensor
+///
+/// Delegates to the From<&ArrayBase> implementation.
 impl<T, S, D> From<ArrayBase<S, D>> for Tensor<T>
 where
     T: TensorType,
@@ -1443,12 +1466,7 @@ where
     D: Dimension,
 {
     fn from(value: ArrayBase<S, D>) -> Self {
-        let dims: Vec<u64> = value.shape().iter().map(|x| *x as u64).collect();
-        let mut tensor: Tensor<T> = Self::new(&dims);
-        for (e, v) in tensor.iter_mut().zip(value.iter()) {
-            e.clone_from(v);
-        }
-        tensor
+        Tensor::from(&value)
     }
 }
 
